div { foo: "A"B; foo: A"B"; foo: "A"B"C"; foo: A"B"C; foo: AB"C"; foo: "A"BC; foo: AB "C"; foo: "A"BC "D"; foo: "A" BCD "E"; foo: A "B"CD "E"; foo: A"B" C "D" "E"; }

div { foo: string; foo: string; foo: string; foo: string; foo: string; foo: string; foo: string; foo: string; foo: string; foo: string; foo: string; }

div { foo: 1; foo: 1; foo: 1; foo: 1; foo: 1; foo: 1; foo: 1; foo: 1; foo: 1; foo: 1; foo: 1; }
