.productportal-link:hover, .productportal-link:focus {
  opacity: .8;
}
@supports (filter: brightness(120%)) {
  .productportal-link:hover, .productportal-link:focus {
    filter: brightness(120%);
  }
}
