.result {
  dquoted: "\b\c\d\e\fghijklmnopqrstuvwxyz";
  dquoted: "[\b\c\d\e\fghijklmnopqrstuvwxyz]";
  dquoted: "\b\c\d\e\fghijklmnopqrstuvwxyz";
  dquoted: "\b\c\d\e\fghijklmnopqrstuvwxyz";
  dquoted: "['\b\c\d\e\fghijklmnopqrstuvwxyz']";
  squoted: "\b\c\d\e\fghijklmnopqrstuvwxyz";
  squoted: "[\b\c\d\e\fghijklmnopqrstuvwxyz]";
  squoted: "\b\c\d\e\fghijklmnopqrstuvwxyz";
  squoted: "\b\c\d\e\fghijklmnopqrstuvwxyz";
  squoted: "['\b\c\d\e\fghijklmnopqrstuvwxyz']";
}
