div {
  /* 0 */
  font: 0;
  /* 1 */
  font: 1;
  /* 2 */
  font: 2;
}
div span {
  /* 2 */
  font: 2;
}
div p {
  /* 2 */
  font: 2;
}

@foo {
  div {
    font: 2;
  }
}
@bar {
  div {
    font: 3;
  }
}
div {
  content: "foo";
  font: fudge;
  width: "block for foo!";
}
