:root {
  --red: #f00;
}

a {
  content: var(--red);
}

a {
  content: var(--red);
}

a {
  content: var(--red);
}

b {
  content: -red;
}

b {
  content: -red;
}

b {
  content: -red;
}

c {
  content: +-red;
}

c {
  content: +-red;
}

c {
  content: +-red;
}

d {
  content: -red;
}

d {
  content: -red;
}

d {
  content: -red;
}

e {
  content: +red;
}

e {
  content: +red;
}

e {
  content: +red;
}
