.button__group, [class*="button__group-"] {
  content: 'fizzbuzz';
}
.button__group .button, .button__group [class*="button--"], [class*="button__group-"] .button, [class*="button__group-"] [class*="button--"] {
  margin-left: 1em;
}
.button__group .button:first-child, .button__group [class*="button--"]:first-child, [class*="button__group-"] .button:first-child, [class*="button__group-"] [class*="button--"]:first-child {
  margin-left: 0;
}

[class*="modal--"][class*="--animate"][class*="--zoom"] {
  content: "fizzbuzz";
}
