.result {
  dquoted: "dquoted";
  dquoted: "[dquoted]";
  dquoted: "dquoted";
  dquoted: "dquoted";
  dquoted: "['dquoted']";
  squoted: "dquoted";
  squoted: "[dquoted]";
  squoted: "dquoted";
  squoted: "dquoted";
  squoted: "['dquoted']"; }
