.result {
  output: "[#{\b\c\d\e\fghijklmnopqrstuvwxyz}]";
  output: "#{\b\c\d\e\fghijklmnopqrstuvwxyz}";
  output: "#{\b\c\d\e\fghijklmnopqrstuvwxyz}";
  output: "['#{\b\c\d\e\fghijklmnopqrstuvwxyz}']";
}
