universal-selector {
  test-01: selector-unify("*", "*");
  test-02: selector-unify("|*", "*");
  test-03: selector-unify("*|*", "*");
  test-04: selector-unify("*", "|*");
  test-05: selector-unify("|*", "|*");
  test-06: selector-unify("*|*", "|*");
  test-07: selector-unify("*", "*|*");
  test-08: selector-unify("|*", "*|*");
  test-09: selector-unify("*|*", "*|*");
}

tag-selector {
  test-1: selector-unify("tag", "*");
  test-2: selector-unify("tag", "|*");
  test-3: selector-unify("tag", "*|*");
  test-4: selector-unify("*", "tag");
  test-5: selector-unify("|*", "tag");
  test-6: selector-unify("*|*", "tag");
}

class-selector {
  test-1: selector-unify(".class", "*");
  test-2: selector-unify(".class", "|*");
  test-3: selector-unify(".class", "*|*");
  test-4: selector-unify("*", ".class");
  test-5: selector-unify("|*", ".class");
  test-6: selector-unify("*|*", ".class");
}

id-selector {
  test-1: selector-unify("#id", "*");
  test-2: selector-unify("#id", "|*");
  test-3: selector-unify("#id", "*|*");
  test-4: selector-unify("*", "#id");
  test-5: selector-unify("|*", "#id");
  test-6: selector-unify("*|*", "#id");
}