.alpha-hex {
  // For Sass 3.5, we just deprecate the previous parsing of hex alpha colors
  // that were previously parsed as IDs. They'll be parsed as colors in 3.6. See
  // sass#2179.
  short-letters: (#AbCd);
  long-letters: (#aBcDeFaB);
  short-type: type-of(#abcd);
  long-type: type-of(#abcdefab);

  // These should still be parsed as ID strings and thus not emit deprecation
  // warnings.
  five-letters:  #abcde;
  seven-letters: #abcdefa;
  nine-letters:  #abcdefabc;
  non-hex-short: #axcd;
  non-hex-long:  #abcxdefa;
}
