div { foo: "A" B; foo: A "B"; foo: "A" B "C"; foo: A "B" C; foo: AB "C"; foo: "A" BC; foo: AB "C"; foo: "A" BC "D"; foo: "A" BCD "E"; foo: A "B" CD "E"; foo: A "B" C "D" "E"; }

div { foo: list; foo: list; foo: list; foo: list; foo: list; foo: list; foo: list; foo: list; foo: list; foo: list; foo: list; }

div { foo: 2; foo: 2; foo: 3; foo: 3; foo: 2; foo: 2; foo: 2; foo: 3; foo: 3; foo: 4; foo: 5; }
