$input: \b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z;
.result {
  output: #{#{$input}};
  output: #{"[#{$input}]"};
  output: #{"#{$input}"};
  output: #{'#{$input}'};
  output: #{"['#{$input}']"};
}
