@function foo($a, $b) {
  @return ($a $b);
}

foo {
  foo: 1px / 2px;
  foo: 1px / round(1.5);
  foo: foo(1px / 2px, 1px / round(1.5));
  foo: missing(1px / 2px, 1px / round(1.5));
  foo: call(missing, 1px / 2px, 1px / round(1.5));
}
