::selection {
  color: rebeccapurple;
}

::-webkit-selection {
  color: rebeccapurple;
}

::-webkit-selection, ::selection {
  color: rebeccapurple;
}

:-webkit-selection {
  color: rebeccapurple;
}

:hover TD {
  color: red;
}

:color red {
  foo: bar;
}

:nth-child(2n+1) SPAN {
  foo: bar;
}
