foo {
  -quotes: true;
  -quotes: true;
  -quotes: true;
  -quotes: false;
  -quotes: false;
  foo: this-string;
  foo: 'this-string';
  foo: "this-string";
  foo: '"this-string"';
  foo: "'this-string'";
}
