foo {
  // c-101: adjust-color(red,$lightness:-101);
  c-100: adjust-color(red,$lightness:-100);
  c-99: adjust-color(red,$lightness:-99);
  c-98: adjust-color(red,$lightness:-98);
  c-97: adjust-color(red,$lightness:-97);
  c-96: adjust-color(red,$lightness:-96);
  c-95: adjust-color(red,$lightness:-95);
  c-94: adjust-color(red,$lightness:-94);
  c-93: adjust-color(red,$lightness:-93);
  c-92: adjust-color(red,$lightness:-92);
  c-91: adjust-color(red,$lightness:-91);
  c-90: adjust-color(red,$lightness:-90);
  c-89: adjust-color(red,$lightness:-89);
  c-88: adjust-color(red,$lightness:-88);
  c-87: adjust-color(red,$lightness:-87);
  c-86: adjust-color(red,$lightness:-86);
  c-85: adjust-color(red,$lightness:-85);
  c-84: adjust-color(red,$lightness:-84);
  c-83: adjust-color(red,$lightness:-83);
  c-82: adjust-color(red,$lightness:-82);
  c-81: adjust-color(red,$lightness:-81);
  c-80: adjust-color(red,$lightness:-80);
  c-79: adjust-color(red,$lightness:-79);
  c-78: adjust-color(red,$lightness:-78);
  c-77: adjust-color(red,$lightness:-77);
  c-76: adjust-color(red,$lightness:-76);
  c-75: adjust-color(red,$lightness:-75);
  c-74: adjust-color(red,$lightness:-74);
  c-73: adjust-color(red,$lightness:-73);
  c-72: adjust-color(red,$lightness:-72);
  c-71: adjust-color(red,$lightness:-71);
  c-70: adjust-color(red,$lightness:-70);
  c-69: adjust-color(red,$lightness:-69);
  c-68: adjust-color(red,$lightness:-68);
  c-67: adjust-color(red,$lightness:-67);
  c-66: adjust-color(red,$lightness:-66);
  c-65: adjust-color(red,$lightness:-65);
  c-64: adjust-color(red,$lightness:-64);
  c-63: adjust-color(red,$lightness:-63);
  c-62: adjust-color(red,$lightness:-62);
  c-61: adjust-color(red,$lightness:-61);
  c-60: adjust-color(red,$lightness:-60);
  c-59: adjust-color(red,$lightness:-59);
  c-58: adjust-color(red,$lightness:-58);
  c-57: adjust-color(red,$lightness:-57);
  c-56: adjust-color(red,$lightness:-56);
  c-55: adjust-color(red,$lightness:-55);
  c-54: adjust-color(red,$lightness:-54);
  c-53: adjust-color(red,$lightness:-53);
  c-52: adjust-color(red,$lightness:-52);
  c-51: adjust-color(red,$lightness:-51);
  c-50: adjust-color(red,$lightness:-50);
  c-49: adjust-color(red,$lightness:-49);
  c-48: adjust-color(red,$lightness:-48);
  c-47: adjust-color(red,$lightness:-47);
  c-46: adjust-color(red,$lightness:-46);
  c-45: adjust-color(red,$lightness:-45);
  c-44: adjust-color(red,$lightness:-44);
  c-43: adjust-color(red,$lightness:-43);
  c-42: adjust-color(red,$lightness:-42);
  c-41: adjust-color(red,$lightness:-41);
  c-40: adjust-color(red,$lightness:-40);
  c-39: adjust-color(red,$lightness:-39);
  c-38: adjust-color(red,$lightness:-38);
  c-37: adjust-color(red,$lightness:-37);
  c-36: adjust-color(red,$lightness:-36);
  c-35: adjust-color(red,$lightness:-35);
  c-34: adjust-color(red,$lightness:-34);
  c-33: adjust-color(red,$lightness:-33);
  c-32: adjust-color(red,$lightness:-32);
  c-31: adjust-color(red,$lightness:-31);
  c-30: adjust-color(red,$lightness:-30);
  c-29: adjust-color(red,$lightness:-29);
  c-28: adjust-color(red,$lightness:-28);
  c-27: adjust-color(red,$lightness:-27);
  c-26: adjust-color(red,$lightness:-26);
  c-25: adjust-color(red,$lightness:-25);
  c-24: adjust-color(red,$lightness:-24);
  c-23: adjust-color(red,$lightness:-23);
  c-22: adjust-color(red,$lightness:-22);
  c-21: adjust-color(red,$lightness:-21);
  c-20: adjust-color(red,$lightness:-20);
  c-19: adjust-color(red,$lightness:-19);
  c-18: adjust-color(red,$lightness:-18);
  c-17: adjust-color(red,$lightness:-17);
  c-16: adjust-color(red,$lightness:-16);
  c-15: adjust-color(red,$lightness:-15);
  c-14: adjust-color(red,$lightness:-14);
  c-13: adjust-color(red,$lightness:-13);
  c-12: adjust-color(red,$lightness:-12);
  c-11: adjust-color(red,$lightness:-11);
  c-10: adjust-color(red,$lightness:-10);
  c-9: adjust-color(red,$lightness:-9);
  c-8: adjust-color(red,$lightness:-8);
  c-7: adjust-color(red,$lightness:-7);
  c-6: adjust-color(red,$lightness:-6);
  c-5: adjust-color(red,$lightness:-5);
  c-4: adjust-color(red,$lightness:-4);
  c-3: adjust-color(red,$lightness:-3);
  c-2: adjust-color(red,$lightness:-2);
  c-1: adjust-color(red,$lightness:-1);
  c0: adjust-color(red,$lightness:0);
  c1: adjust-color(red,$lightness:1);
  c2: adjust-color(red,$lightness:2);
  c3: adjust-color(red,$lightness:3);
  c4: adjust-color(red,$lightness:4);
  c5: adjust-color(red,$lightness:5);
  c6: adjust-color(red,$lightness:6);
  c7: adjust-color(red,$lightness:7);
  c8: adjust-color(red,$lightness:8);
  c9: adjust-color(red,$lightness:9);
  c10: adjust-color(red,$lightness:10);
  c11: adjust-color(red,$lightness:11);
  c12: adjust-color(red,$lightness:12);
  c13: adjust-color(red,$lightness:13);
  c14: adjust-color(red,$lightness:14);
  c15: adjust-color(red,$lightness:15);
  c16: adjust-color(red,$lightness:16);
  c17: adjust-color(red,$lightness:17);
  c18: adjust-color(red,$lightness:18);
  c19: adjust-color(red,$lightness:19);
  c20: adjust-color(red,$lightness:20);
  c21: adjust-color(red,$lightness:21);
  c22: adjust-color(red,$lightness:22);
  c23: adjust-color(red,$lightness:23);
  c24: adjust-color(red,$lightness:24);
  c25: adjust-color(red,$lightness:25);
  c26: adjust-color(red,$lightness:26);
  c27: adjust-color(red,$lightness:27);
  c28: adjust-color(red,$lightness:28);
  c29: adjust-color(red,$lightness:29);
  c30: adjust-color(red,$lightness:30);
  c31: adjust-color(red,$lightness:31);
  c32: adjust-color(red,$lightness:32);
  c33: adjust-color(red,$lightness:33);
  c34: adjust-color(red,$lightness:34);
  c35: adjust-color(red,$lightness:35);
  c36: adjust-color(red,$lightness:36);
  c37: adjust-color(red,$lightness:37);
  c38: adjust-color(red,$lightness:38);
  c39: adjust-color(red,$lightness:39);
  c40: adjust-color(red,$lightness:40);
  c41: adjust-color(red,$lightness:41);
  c42: adjust-color(red,$lightness:42);
  c43: adjust-color(red,$lightness:43);
  c44: adjust-color(red,$lightness:44);
  c45: adjust-color(red,$lightness:45);
  c46: adjust-color(red,$lightness:46);
  c47: adjust-color(red,$lightness:47);
  c48: adjust-color(red,$lightness:48);
  c49: adjust-color(red,$lightness:49);
  c50: adjust-color(red,$lightness:50);
  c51: adjust-color(red,$lightness:51);
  c52: adjust-color(red,$lightness:52);
  c53: adjust-color(red,$lightness:53);
  c54: adjust-color(red,$lightness:54);
  c55: adjust-color(red,$lightness:55);
  c56: adjust-color(red,$lightness:56);
  c57: adjust-color(red,$lightness:57);
  c58: adjust-color(red,$lightness:58);
  c59: adjust-color(red,$lightness:59);
  c60: adjust-color(red,$lightness:60);
  c61: adjust-color(red,$lightness:61);
  c62: adjust-color(red,$lightness:62);
  c63: adjust-color(red,$lightness:63);
  c64: adjust-color(red,$lightness:64);
  c65: adjust-color(red,$lightness:65);
  c66: adjust-color(red,$lightness:66);
  c67: adjust-color(red,$lightness:67);
  c68: adjust-color(red,$lightness:68);
  c69: adjust-color(red,$lightness:69);
  c70: adjust-color(red,$lightness:70);
  c71: adjust-color(red,$lightness:71);
  c72: adjust-color(red,$lightness:72);
  c73: adjust-color(red,$lightness:73);
  c74: adjust-color(red,$lightness:74);
  c75: adjust-color(red,$lightness:75);
  c76: adjust-color(red,$lightness:76);
  c77: adjust-color(red,$lightness:77);
  c78: adjust-color(red,$lightness:78);
  c79: adjust-color(red,$lightness:79);
  c80: adjust-color(red,$lightness:80);
  c81: adjust-color(red,$lightness:81);
  c82: adjust-color(red,$lightness:82);
  c83: adjust-color(red,$lightness:83);
  c84: adjust-color(red,$lightness:84);
  c85: adjust-color(red,$lightness:85);
  c86: adjust-color(red,$lightness:86);
  c87: adjust-color(red,$lightness:87);
  c88: adjust-color(red,$lightness:88);
  c89: adjust-color(red,$lightness:89);
  c90: adjust-color(red,$lightness:90);
  c91: adjust-color(red,$lightness:91);
  c92: adjust-color(red,$lightness:92);
  c93: adjust-color(red,$lightness:93);
  c94: adjust-color(red,$lightness:94);
  c95: adjust-color(red,$lightness:95);
  c96: adjust-color(red,$lightness:96);
  c97: adjust-color(red,$lightness:97);
  c98: adjust-color(red,$lightness:98);
  c99: adjust-color(red,$lightness:99);
  c100: adjust-color(red,$lightness:100);
  // c101: adjust-color(red,$lightness:101);
}
