a {
  q: silver;
  r: #ddd;
  s: green;
  t: #00FF00;
  u: lime;
  v: #0f0;
  w: lime;
  x: rgba(0, 255, 0, 0.5);
  y: lime;
  z: #00ff01; }

b {
  q: 1px solid silver;
  r: 1px solid #ddd;
  s: 1px solid green;
  t: 1px solid #00FF00;
  u: 1px solid lime;
  v: 1px solid #0f0;
  w: 1px solid lime;
  x: 1px solid rgba(0, 255, 0, 0.5);
  y: 1px solid lime;
  z: 1px solid #00ff01; }

c {
  q: silver;
  r: #ddd;
  s: green;
  t: #00FF00;
  u: lime;
  v: #0f0;
  w: lime;
  x: rgba(0, 255, 0, 0.5);
  y: lime;
  z: #00ff01; }

d {
  q: 1px solid silver;
  r: 1px solid #ddd;
  s: 1px solid green;
  t: 1px solid #00FF00;
  u: 1px solid lime;
  v: 1px solid #0f0;
  w: 1px solid lime;
  x: 1px solid rgba(0, 255, 0, 0.5);
  y: 1px solid lime;
  z: 1px solid #00ff01; }
