.test-1 {
  @for $i from 1 through 3 {
    content: $i;
  }
}

.test-2 {
  @for $i from 3 through 1 {
    content: $i;
  }
}

.test-3 {
  @for $i from 1 to 3 {
    content: $i;
  }
}

.test-4 {
  @for $i from 3 to 1 {
    content: $i;
  }
}
