$prop: display;
$val: flow-root;

@mixin supports($prop, $val) {
  @supports ($prop: $val) {
    $prop: $val;
  }
}

div {
  @include supports($prop, $val);
}

div {
  @supports ($prop: $val) {
    #{$prop}: $val;
  }
}
