a {
  foo: 2em;
  bar: 2em;
  a: 1;
  a: 4em;
  a: 0em;
  foo: 2px;
  bar: 2em;
  foo: 2em;
  bar: 2px;
  bar: 2px;
  bar: 2px;
  a: 2em;
  a: 1;
  a: 1;
  foo: 2px;
  a: 2em;
  foo: 2px;
  a: 2em; }
