.is-bracketed {
  unbracketed-empty: is-bracketed(());
  unbracketed-singleton: is-bracketed(foo);
  unbracketed-multiple: is-bracketed(foo bar);
  bracketed-empty: is-bracketed([]);
  bracketed-singleton: is-bracketed([foo]);
  bracketed-multiple: is-bracketed([foo bar]);
}