.test
  foo: bar
  ~
    tilde: true
  +
    adjancent: true
  >
    child: true
  *
    universal: true
  [foo]
    attribute: true

@mixin selector-2()
  foo: bar

.selector-0
  + .selector-1
    color: rebeccapurple
  = selector-2
    color: yellow

multiple, lines,
separated by,
commas
  and,
  indented
    x: y
