foo bar baz { bam: true; }
bar baz foo { bam: true; }

foo bar + baz { bam: true; }
bar + baz foo { bam: true; }

foo bar > baz { bam: true; }
bar > baz foo { bam: true; }

foo bar ~ baz { bam: true; }
bar ~ baz foo { bam: true; }

foo bar /deep/ baz { bam: true; }
bar /deep/ baz foo { bam: true; }
