test {
  /* Convert to px  */
  px-to-px: 0px + 1px;
  pt-to-px: 0px + 1pt;
  pc-to-px: 0px + 1pc;
  in-to-px: 0px + 1in;
  mm-to-px: 0px + 1mm;
  cm-to-px: 0px + 1cm;
  /* Convert to pt  */
  px-to-pt: 0pt + 1px;
  pt-to-pt: 0pt + 1pt;
  pc-to-pt: 0pt + 1pc;
  in-to-pt: 0pt + 1in;
  mm-to-pt: 0pt + 1mm;
  cm-to-pt: 0pt + 1cm;
  /* Convert to pc  */
  px-to-pc: 0pc + 1px;
  pt-to-pc: 0pc + 1pt;
  pc-to-pc: 0pc + 1pc;
  in-to-pc: 0pc + 1in;
  mm-to-pc: 0pc + 1mm;
  cm-to-pc: 0pc + 1cm;
  /* Convert to in  */
  px-to-in: 0in + 1px;
  pt-to-in: 0in + 1pt;
  pc-to-in: 0in + 1pc;
  in-to-in: 0in + 1in;
  mm-to-in: 0in + 1mm;
  cm-to-in: 0in + 1cm;
  /* Convert to mm  */
  px-to-mm: 0mm + 1px;
  pt-to-mm: 0mm + 1pt;
  pc-to-mm: 0mm + 1pc;
  in-to-mm: 0mm + 1in;
  mm-to-mm: 0mm + 1mm;
  cm-to-mm: 0mm + 1cm; 
  /* Convert to cm  */
  px-to-cm: 0cm + 1px;
  pt-to-cm: 0cm + 1pt;
  pc-to-cm: 0cm + 1pc;
  in-to-cm: 0cm + 1in;
  mm-to-cm: 0cm + 1mm;
  cm-to-cm: 0cm + 1cm;   
}
