.foo {
  parse: .foo; }

#foo {
  parse: #foo; }

.bar a {
  parse: .bar a; }

.bar,
.baz {
  parse: .bar, .baz; }

.where .qux.waldo .final {
  parse: .where .qux.waldo .final; }

inside.of #a .mixin {
  parse: inside.of #a .mixin; }
