test { /* Convert to px  */ px-to-px: 1px; pt-to-px: 1.33333px; pc-to-px: 16px; in-to-px: 96px; mm-to-px: 3.77953px; cm-to-px: 37.79528px; /* Convert to pt  */ px-to-pt: 0.75pt; pt-to-pt: 1pt; pc-to-pt: 12pt; in-to-pt: 72pt; mm-to-pt: 2.83465pt; cm-to-pt: 28.34646pt; /* Convert to pc  */ px-to-pc: 0.0625pc; pt-to-pc: 0.08333pc; pc-to-pc: 1pc; in-to-pc: 6pc; mm-to-pc: 0.23622pc; cm-to-pc: 2.3622pc; /* Convert to in  */ px-to-in: 0.01042in; pt-to-in: 0.01389in; pc-to-in: 0.16667in; in-to-in: 1in; mm-to-in: 0.03937in; cm-to-in: 0.3937in; /* Convert to mm  */ px-to-mm: 0.26458mm; pt-to-mm: 0.35278mm; pc-to-mm: 4.23333mm; in-to-mm: 25.4mm; mm-to-mm: 1mm; cm-to-mm: 10mm; /* Convert to cm  */ px-to-cm: 0.02646cm; pt-to-cm: 0.03528cm; pc-to-cm: 0.42333cm; in-to-cm: 2.54cm; mm-to-cm: 0.1cm; cm-to-cm: 1cm; }
