p {
  color: rgb(255, 128, 0);
  color: red green blue;
  color: (red) (green) (blue);
  color: red + green;
  color: red + hux;
  color: unquote("red") + green;
  color: unquote(red) + green;
  color: unquote(0xf00);
  foo: rgb(200, 150%, 170%);
}