foo {
  c0: darken(white, 0%);
  c1: darken(white, 1%);
  c2: darken(white, 2%);
  c3: darken(white, 3%);
  c4: darken(white, 4%);
  c5: darken(white, 5%);
  c6: darken(white, 6%);
  c7: darken(white, 7%);
  c8: darken(white, 8%);
  c9: darken(white, 9%);
  c10: darken(white, 10%);
  c11: darken(white, 11%);
  c12: darken(white, 12%);
  c13: darken(white, 13%);
  c14: darken(white, 14%);
  c15: darken(white, 15%);
  c16: darken(white, 16%);
  c17: darken(white, 17%);
  c18: darken(white, 18%);
  c19: darken(white, 19%);
  c20: darken(white, 20%);
  c21: darken(white, 21%);
  c22: darken(white, 22%);
  c23: darken(white, 23%);
  c24: darken(white, 24%);
  c25: darken(white, 25%);
  c26: darken(white, 26%);
  c27: darken(white, 27%);
  c28: darken(white, 28%);
  c29: darken(white, 29%);
  c30: darken(white, 30%);
  c31: darken(white, 31%);
  c32: darken(white, 32%);
  c33: darken(white, 33%);
  c34: darken(white, 34%);
  c35: darken(white, 35%);
  c36: darken(white, 36%);
  c37: darken(white, 37%);
  c38: darken(white, 38%);
  c39: darken(white, 39%);
  c40: darken(white, 40%);
  c41: darken(white, 41%);
  c42: darken(white, 42%);
  c43: darken(white, 43%);
  c44: darken(white, 44%);
  c45: darken(white, 45%);
  c46: darken(white, 46%);
  c47: darken(white, 47%);
  c48: darken(white, 48%);
  c49: darken(white, 49%);
  c50: darken(white, 50%);
  c51: darken(white, 51%);
  c52: darken(white, 52%);
  c53: darken(white, 53%);
  c54: darken(white, 54%);
  c55: darken(white, 55%);
  c56: darken(white, 56%);
  c57: darken(white, 57%);
  c58: darken(white, 58%);
  c59: darken(white, 59%);
  c60: darken(white, 60%);
  c61: darken(white, 61%);
  c62: darken(white, 62%);
  c63: darken(white, 63%);
  c64: darken(white, 64%);
  c65: darken(white, 65%);
  c66: darken(white, 66%);
  c67: darken(white, 67%);
  c68: darken(white, 68%);
  c69: darken(white, 69%);
  c70: darken(white, 70%);
  c71: darken(white, 71%);
  c72: darken(white, 72%);
  c73: darken(white, 73%);
  c74: darken(white, 74%);
  c75: darken(white, 75%);
  c76: darken(white, 76%);
  c77: darken(white, 77%);
  c78: darken(white, 78%);
  c79: darken(white, 79%);
  c80: darken(white, 80%);
  c81: darken(white, 81%);
  c82: darken(white, 82%);
  c83: darken(white, 83%);
  c84: darken(white, 84%);
  c85: darken(white, 85%);
  c86: darken(white, 86%);
  c87: darken(white, 87%);
  c88: darken(white, 88%);
  c89: darken(white, 89%);
  c90: darken(white, 90%);
  c91: darken(white, 91%);
  c92: darken(white, 92%);
  c93: darken(white, 93%);
  c94: darken(white, 94%);
  c95: darken(white, 95%);
  c96: darken(white, 96%);
  c97: darken(white, 97%);
  c98: darken(white, 98%);
  c99: darken(white, 99%);
  c100: darken(white, 100%);
}
