.result {
  output: "\b\c\d\e\fghijklmnopqrstuvwxyz";
  output: 
ghijklmnopqrstuvwxyz;
  output: "[\b\c\d\e\fghijklmnopqrstuvwxyz]";
  output: "\b\c\d\e\fghijklmnopqrstuvwxyz";
  output: "\b\c\d\e\fghijklmnopqrstuvwxyz";
  output: "['\b\c\d\e\fghijklmnopqrstuvwxyz']";
}
