foo {
  // c-1: change-color(black,$alpha:-1);
  c0: change-color(black,$alpha:0.0);
  c1: change-color(black,$alpha:0.1);
  c2: change-color(black,$alpha:0.2);
  c3: change-color(black,$alpha:0.3);
  c4: change-color(black,$alpha:0.4);
  c5: change-color(black,$alpha:0.5);
  c6: change-color(black,$alpha:0.6);
  c7: change-color(black,$alpha:0.7);
  c8: change-color(black,$alpha:0.8);
  c9: change-color(black,$alpha:0.9);
  c10: change-color(black,$alpha:1);
  // c11: change-color(black,$alpha:1.1);
  // c12: change-color(black,$alpha:2);
}
