div{background-image:image-url("test.png", true);hey:4;ho:hello;hee:fudge;fudge:walnut}@media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2){div{background-image:image-url("test@2x.png");-webkit-background-size:100px 300px}}span{blah:"foo bar";bleh:image-url("foo bar")}div{foo-x:1;foo-y:2;foo-x:1;foo-y:2}div{bar-x:1;bar-y:2;bar-x:1;bar-y:default;bar-x:n1;bar-y:n2;bar-x:n1;bar-y:default;blah:hello}
