@asdf .~@#$%^&*()_-+=[]|:<>,.?/;

@asdf "f'o" 'b"r' url(baz) url("qux");

@asdf foo //
      bar;

@asdf foo /* bar */ baz;

@asdf 3;

@asdf "foo bar baz";

@asdf 'foo bar baz';

@asdf url(http://).com/);

@asdf url("http://).com/");
