div{color:red;background:blue;margin:10px 5px}div span{font-weight:bold;display:inline-block}div span a{text-decoration:none;color:green;border:1px bloo blee red}div empty not_empty{blah:blah;bloo:bloo}div p{padding:10px 8%;-webkit-box-sizing:hux}div h1{color:"a 'red' and \"blue\" value"}div{f:g}div empty span{a:b}div empty_with_comment span{c:d}
