.foo {
  type: list;
  length: 1;
  content: .foo;
  index: 1;
  length: 1;
  type: list;
  content: .foo; }

.bar a {
  type: list;
  length: 1;
  content: .bar a;
  index: 1;
  length: 2;
  type: list;
  content: .bar a; }

.bar,
.baz {
  type: list;
  length: 2;
  content: .bar, .baz;
  index: 1;
  length: 1;
  type: list;
  content: .bar;
  index: 2;
  length: 1;
  type: list;
  content: .baz; }

.where .qux.waldo .final {
  type: list;
  length: 1;
  content: .where .qux.waldo .final;
  index: 1;
  length: 3;
  type: list;
  content: .where .qux.waldo .final; }
