.foo {
    a: selector-nest('.foo', '.bar > .baz');
    b: selector-nest('.foo', '.bar ~ .baz');
    c: selector-nest('.foo', '.bar + .baz');
    d: selector-nest('.foo > .bar', '.baz');
    e: selector-nest('.foo ~ .bar', '.baz');
    f: selector-nest('.foo + .bar', '.baz');
}
