round {
  positive-middle: round(1.5);
  positive-high: round(1.51);
  positive-low: round(1.49);

  negative-middle: round(-1.5);
  negative-high: round(-1.51);
  negative-low: round(-1.49);

  almost-middle: round(1.49999999999);
  with-units: round(1.1px);
  with-named: round($number: 1.1px);
}
