div {
  grarh: bool;
  f: c d e f;
  fa: a, b, c d e f;
  fv: c d e f;
  ft: arglist;
  fj: 1 2 3 c d e f;
  fjt: list;
  fkt: list;
  hoopla: 5;
  boopla: number;
  koopla: number;
  ba: a, b, c d e f;
  bv: c d e f;
  bt: list;
  bj: 1 2 3 c d e f;
  bjt: list;
  grarh: bool;
  f: c d e;
  fa: a, b, c d e;
  fv: c d e;
  ft: arglist;
  fj: 1 2 3 c d e;
  fjt: list;
  fkt: list;
  hoopla: 5;
  boopla: number;
  koopla: number;
  grarh: bool;
  f: d e;
  fa: a, c, d e;
  fv: d e;
  ft: arglist;
  fj: 1 2 3 d e;
  fjt: list;
  fkt: list;
  hoopla: 5;
  boopla: number;
  koopla: number;
  grarh: bool;
  f: hoo ha;
  fa: a, hey, hoo ha;
  fv: hoo ha;
  ft: arglist;
  fj: 1 2 3 hoo ha;
  fjt: list;
  fkt: list;
  hoopla: 5;
  boopla: number;
  koopla: number;
  new: string;
}

div {
  a: list;
  b: bool;
  c: number;
}
