.test-1 {
  content: null;
  content: null;
  content: false;
  content: true;
  content: 42;
  content: 42.3;
  content: 42px;
  content: "string";
  content: 1, 2, 3;
  content: (a: 1, b: 2, c: 3); }
