foo { content: ABCD; content: ABCD; content: ABCD; content: "ABCD"; content: "ABCD"; content: "ABCD"; content: "ABCD"; content: "ABCD"; content: "ABCD"; content: ABCD; content: ABCD; content: ABCD; content: "ABCD"; content: "ABCD"; content: "ABCD"; content: "ABCD"; content: "ABCD"; content: "ABCD"; content: ABCDefg; content: ABCDefg; content: ABCDefg; content: "ABCDefg"; content: "ABCDefg"; content: "ABCDefg"; content: "ABCDefg"; content: "ABCDefg"; content: "ABCDefg"; content: ABCD; content: ABCD; content: ABCD; content: "ABCD"; content: "ABCD"; content: "ABCD"; content: "ABCD"; content: "ABCD"; content: "ABCD"; }
