foo {
  content: (red: "literal", transparent: "literal");
  content: ("red": "quoted", transparent: "quoted");
  content: (red: "interpolated", transparent: "quoted"); }

bar {
  content: (red: "literal", transparent: "quoted", "red": "quoted");
  content: (red: "literal", transparent: "literal", red: "interpolated", transparent: "quoted");
  content: ("red": "interpolated", transparent: "quoted", transparent: "quoted"); }
