foo {
  bar: baz; }

baz {
  bar: foo; }

@media screen and (max-width: 2) {
  foo {
    bar: baz; }

  baz {
    bar: foo; } }
@media screen and (min-width: 1) {
  foo {
    bar: baz; }

  baz {
    bar: foo; } }
@media screen and (min-width: 1) {
  foo {
    bar: baz; }

  baz {
    bar: foo; } }
@media screen and (min-width: 1) and (max-width: 2) {
  foo {
    bar: baz; }

  baz {
    bar: foo; } }
