foo {
  @if true {
    foo: true;
  } @elseif true {
    foo: false;
  } @else {
    foo: false;
  }

  @if true {
    bar: true;
  } @else if true {
    bar: false;
  } @else {
    bar: false;
  }
}
