.result {
  dquoted: "l\\iteral";
  dquoted: "[l\\iteral]";
  dquoted: "l\\iteral";
  dquoted: "l\\iteral";
  dquoted: "['l\\iteral']";
  squoted: "l\\iteral";
  squoted: "[l\\iteral]";
  squoted: "l\\iteral";
  squoted: "l\\iteral";
  squoted: "['l\\iteral']";
}
