.result {
  dquoted: "[ ,foo,    ]";
  dquoted: "[[ ,foo,    ]]";
  dquoted: "[ ,foo,    ]";
  dquoted: "[ ,foo,    ]";
  dquoted: "['[ ,foo,    ]']";
  squoted: "[ ,foo,    ]";
  squoted: "[[ ,foo,    ]]";
  squoted: "[ ,foo,    ]";
  squoted: "[ ,foo,    ]";
  squoted: "['[ ,foo,    ]']"; }
