$foo: 5px;
a {
    background: url('img.png') no-repeat 6px 0 / #{$foo};
    background: url('img.png') no-repeat 6px 1 / #{$foo};
    background: url('img.png') no-repeat 6px 1px / #{$foo};
    background: url('img.png') no-repeat 6px #{$foo} / 0;
    background: url('img.png') no-repeat 6px #{$foo} / 1;
    background: url('img.png') no-repeat 6px #{$foo} / 1px;
}
