div {
  color: #181818;
}

@-webkit-keyframes uiDelayedFadeIn {
  0% {
    opacity: 0;
  }
  50% {
    opacity: 0.5;
  }
  100% {
    opacity: 1;
  }
}
@-webkit-keyframes bounce {
  from {
    left: 0px;
  }
  to {
    left: 200px;
  }
}
@-webkit-keyframes bounce {
  blah: blee;
}
foo div {
  color: red;
}

@-moz-document url-prefix() {
  .fl {
    float: left;
    margin: 12px 4px 0 0;
    padding: 0;
    font-size: 65px;
    line-height: 62%;
    color: #ba1820;
  }

  .fs {
    float: left;
    margin: 12px 4px 10px 0;
    padding: 0;
    font-size: 65px;
    line-height: 62%;
    color: #ba1820;
  }
}
