div {
  color: scale-color(red, $red: -23%);
  color: scale-color(hsl(120, 70, 80), $lightness: 50%);
  color: scale-color(rgb(200, 150, 170), $green: -40%, $blue: 70%);
  color: scale-color(hsl(200, 70, 80), $saturation: -90%, $alpha: 10%);
  blah: #d4f7d4;
}