.question-mark {
  one-digit-question-only: U+?;
  four-digit-question-only: U+????;
  six-digit-question-only: U+??????;
  two-digit-half-question: U+A?;
  six-digit-half-question: U+123???;
  followed-by-ident: U+A? BCDE;
  followed-by-minus: U+A? -BCDE;
  followed-by-number: U+A?-1234;
}
