a,b{color:red;background:blue}c,d{color:gray}c e,c f,d e,d f{background:blue;padding:10px 5px}c g,c h,d g,d h{blah:blah;bloo:bloo}c i,c j,d i,d j{foo:goo}c i k,c i l,c j k,c j l,d i k,d i l,d j k,d j l{hoo:boo}c i k m,c i k n,c i k o,c i l m,c i l n,c i l o,c j k m,c j k n,c j k o,c j l m,c j l n,c j l o,d i k m,d i k n,d i k o,d i l m,d i l n,d i l o,d j k m,d j k n,d j k o,d j l m,d j l n,d j l o{wow:we are far inside;but:it still works}
