foo {
  // c-1: change-color(black,$red:-1);
  c0: change-color(black,$red:0);
  c1: change-color(black,$red:1);
  c2: change-color(black,$red:2);
  c3: change-color(black,$red:3);
  c4: change-color(black,$red:4);
  c5: change-color(black,$red:5);
  c6: change-color(black,$red:6);
  c7: change-color(black,$red:7);
  c8: change-color(black,$red:8);
  c9: change-color(black,$red:9);
  c10: change-color(black,$red:10);
  c11: change-color(black,$red:11);
  c12: change-color(black,$red:12);
  c13: change-color(black,$red:13);
  c14: change-color(black,$red:14);
  c15: change-color(black,$red:15);
  c16: change-color(black,$red:16);
  c17: change-color(black,$red:17);
  c18: change-color(black,$red:18);
  c19: change-color(black,$red:19);
  c20: change-color(black,$red:20);
  c21: change-color(black,$red:21);
  c22: change-color(black,$red:22);
  c23: change-color(black,$red:23);
  c24: change-color(black,$red:24);
  c25: change-color(black,$red:25);
  c26: change-color(black,$red:26);
  c27: change-color(black,$red:27);
  c28: change-color(black,$red:28);
  c29: change-color(black,$red:29);
  c30: change-color(black,$red:30);
  c31: change-color(black,$red:31);
  c32: change-color(black,$red:32);
  c33: change-color(black,$red:33);
  c34: change-color(black,$red:34);
  c35: change-color(black,$red:35);
  c36: change-color(black,$red:36);
  c37: change-color(black,$red:37);
  c38: change-color(black,$red:38);
  c39: change-color(black,$red:39);
  c40: change-color(black,$red:40);
  c41: change-color(black,$red:41);
  c42: change-color(black,$red:42);
  c43: change-color(black,$red:43);
  c44: change-color(black,$red:44);
  c45: change-color(black,$red:45);
  c46: change-color(black,$red:46);
  c47: change-color(black,$red:47);
  c48: change-color(black,$red:48);
  c49: change-color(black,$red:49);
  c50: change-color(black,$red:50);
  c51: change-color(black,$red:51);
  c52: change-color(black,$red:52);
  c53: change-color(black,$red:53);
  c54: change-color(black,$red:54);
  c55: change-color(black,$red:55);
  c56: change-color(black,$red:56);
  c57: change-color(black,$red:57);
  c58: change-color(black,$red:58);
  c59: change-color(black,$red:59);
  c60: change-color(black,$red:60);
  c61: change-color(black,$red:61);
  c62: change-color(black,$red:62);
  c63: change-color(black,$red:63);
  c64: change-color(black,$red:64);
  c65: change-color(black,$red:65);
  c66: change-color(black,$red:66);
  c67: change-color(black,$red:67);
  c68: change-color(black,$red:68);
  c69: change-color(black,$red:69);
  c70: change-color(black,$red:70);
  c71: change-color(black,$red:71);
  c72: change-color(black,$red:72);
  c73: change-color(black,$red:73);
  c74: change-color(black,$red:74);
  c75: change-color(black,$red:75);
  c76: change-color(black,$red:76);
  c77: change-color(black,$red:77);
  c78: change-color(black,$red:78);
  c79: change-color(black,$red:79);
  c80: change-color(black,$red:80);
  c81: change-color(black,$red:81);
  c82: change-color(black,$red:82);
  c83: change-color(black,$red:83);
  c84: change-color(black,$red:84);
  c85: change-color(black,$red:85);
  c86: change-color(black,$red:86);
  c87: change-color(black,$red:87);
  c88: change-color(black,$red:88);
  c89: change-color(black,$red:89);
  c90: change-color(black,$red:90);
  c91: change-color(black,$red:91);
  c92: change-color(black,$red:92);
  c93: change-color(black,$red:93);
  c94: change-color(black,$red:94);
  c95: change-color(black,$red:95);
  c96: change-color(black,$red:96);
  c97: change-color(black,$red:97);
  c98: change-color(black,$red:98);
  c99: change-color(black,$red:99);
  c100: change-color(black,$red:100);
  c101: change-color(black,$red:101);
  c102: change-color(black,$red:102);
  c103: change-color(black,$red:103);
  c104: change-color(black,$red:104);
  c105: change-color(black,$red:105);
  c106: change-color(black,$red:106);
  c107: change-color(black,$red:107);
  c108: change-color(black,$red:108);
  c109: change-color(black,$red:109);
  c110: change-color(black,$red:110);
  c111: change-color(black,$red:111);
  c112: change-color(black,$red:112);
  c113: change-color(black,$red:113);
  c114: change-color(black,$red:114);
  c115: change-color(black,$red:115);
  c116: change-color(black,$red:116);
  c117: change-color(black,$red:117);
  c118: change-color(black,$red:118);
  c119: change-color(black,$red:119);
  c120: change-color(black,$red:120);
  c121: change-color(black,$red:121);
  c122: change-color(black,$red:122);
  c123: change-color(black,$red:123);
  c124: change-color(black,$red:124);
  c125: change-color(black,$red:125);
  c126: change-color(black,$red:126);
  c127: change-color(black,$red:127);
  c128: change-color(black,$red:128);
  c129: change-color(black,$red:129);
  c130: change-color(black,$red:130);
  c131: change-color(black,$red:131);
  c132: change-color(black,$red:132);
  c133: change-color(black,$red:133);
  c134: change-color(black,$red:134);
  c135: change-color(black,$red:135);
  c136: change-color(black,$red:136);
  c137: change-color(black,$red:137);
  c138: change-color(black,$red:138);
  c139: change-color(black,$red:139);
  c140: change-color(black,$red:140);
  c141: change-color(black,$red:141);
  c142: change-color(black,$red:142);
  c143: change-color(black,$red:143);
  c144: change-color(black,$red:144);
  c145: change-color(black,$red:145);
  c146: change-color(black,$red:146);
  c147: change-color(black,$red:147);
  c148: change-color(black,$red:148);
  c149: change-color(black,$red:149);
  c150: change-color(black,$red:150);
  c151: change-color(black,$red:151);
  c152: change-color(black,$red:152);
  c153: change-color(black,$red:153);
  c154: change-color(black,$red:154);
  c155: change-color(black,$red:155);
  c156: change-color(black,$red:156);
  c157: change-color(black,$red:157);
  c158: change-color(black,$red:158);
  c159: change-color(black,$red:159);
  c160: change-color(black,$red:160);
  c161: change-color(black,$red:161);
  c162: change-color(black,$red:162);
  c163: change-color(black,$red:163);
  c164: change-color(black,$red:164);
  c165: change-color(black,$red:165);
  c166: change-color(black,$red:166);
  c167: change-color(black,$red:167);
  c168: change-color(black,$red:168);
  c169: change-color(black,$red:169);
  c170: change-color(black,$red:170);
  c171: change-color(black,$red:171);
  c172: change-color(black,$red:172);
  c173: change-color(black,$red:173);
  c174: change-color(black,$red:174);
  c175: change-color(black,$red:175);
  c176: change-color(black,$red:176);
  c177: change-color(black,$red:177);
  c178: change-color(black,$red:178);
  c179: change-color(black,$red:179);
  c180: change-color(black,$red:180);
  c181: change-color(black,$red:181);
  c182: change-color(black,$red:182);
  c183: change-color(black,$red:183);
  c184: change-color(black,$red:184);
  c185: change-color(black,$red:185);
  c186: change-color(black,$red:186);
  c187: change-color(black,$red:187);
  c188: change-color(black,$red:188);
  c189: change-color(black,$red:189);
  c190: change-color(black,$red:190);
  c191: change-color(black,$red:191);
  c192: change-color(black,$red:192);
  c193: change-color(black,$red:193);
  c194: change-color(black,$red:194);
  c195: change-color(black,$red:195);
  c196: change-color(black,$red:196);
  c197: change-color(black,$red:197);
  c198: change-color(black,$red:198);
  c199: change-color(black,$red:199);
  c200: change-color(black,$red:200);
  c201: change-color(black,$red:201);
  c202: change-color(black,$red:202);
  c203: change-color(black,$red:203);
  c204: change-color(black,$red:204);
  c205: change-color(black,$red:205);
  c206: change-color(black,$red:206);
  c207: change-color(black,$red:207);
  c208: change-color(black,$red:208);
  c209: change-color(black,$red:209);
  c210: change-color(black,$red:210);
  c211: change-color(black,$red:211);
  c212: change-color(black,$red:212);
  c213: change-color(black,$red:213);
  c214: change-color(black,$red:214);
  c215: change-color(black,$red:215);
  c216: change-color(black,$red:216);
  c217: change-color(black,$red:217);
  c218: change-color(black,$red:218);
  c219: change-color(black,$red:219);
  c220: change-color(black,$red:220);
  c221: change-color(black,$red:221);
  c222: change-color(black,$red:222);
  c223: change-color(black,$red:223);
  c224: change-color(black,$red:224);
  c225: change-color(black,$red:225);
  c226: change-color(black,$red:226);
  c227: change-color(black,$red:227);
  c228: change-color(black,$red:228);
  c229: change-color(black,$red:229);
  c230: change-color(black,$red:230);
  c231: change-color(black,$red:231);
  c232: change-color(black,$red:232);
  c233: change-color(black,$red:233);
  c234: change-color(black,$red:234);
  c235: change-color(black,$red:235);
  c236: change-color(black,$red:236);
  c237: change-color(black,$red:237);
  c238: change-color(black,$red:238);
  c239: change-color(black,$red:239);
  c240: change-color(black,$red:240);
  c241: change-color(black,$red:241);
  c242: change-color(black,$red:242);
  c243: change-color(black,$red:243);
  c244: change-color(black,$red:244);
  c245: change-color(black,$red:245);
  c246: change-color(black,$red:246);
  c247: change-color(black,$red:247);
  c248: change-color(black,$red:248);
  c249: change-color(black,$red:249);
  c250: change-color(black,$red:250);
  c251: change-color(black,$red:251);
  c252: change-color(black,$red:252);
  c253: change-color(black,$red:253);
  c254: change-color(black,$red:254);
  c255: change-color(black,$red:255);
  // c256: change-color(black,$red:256);
}
