foo {
  color: blue; }
  bar {
    color: red; }

foo {
  color: blue; }
  bar {
    color: red; }

foo {
  color: blue; }
  bar baz {
    color: red; }

foo {
  color: blue; }
  bar baz {
    color: red; }
