.name-interpolation {
  --entire: 3;
  --first-hyphen: 3;
  --only-name: 1 + 2;
  --only-name-interp-value: 3;
  --initial-interp: 1 + 2;
  --middle-interp: 1 + 2;
  --final-interp: 1 + 2;
  --double-interp: 1 + 2;
}
