.nesting-characters {
  --parens: (foo; (bar: baz;) bang!);
  --curly: {foo; {bar: baz;} bang!};
  --square: [foo; [bar: baz;] bang!];
  --multiple: [({{([])}})];
  --nested-props: {foo: bar;};
  --ambiguous:foo {bar: baz;};
}
