@import "../assert_helpers";

test {
  a : assert_strict_superselector('.foo', '.foo.bar');
  b : assert_strict_superselector('.bar', '.foo.bar');
  c : assert_strict_superselector('a', 'a#b');
  d : assert_strict_superselector('#b', 'a#b');
}
