.color-functions {
  hue: 0deg;
  hue-type: number;
  hue-unit: "deg";
  hue-comparable: true;
  x: true;
  x: true;
  x: true;
  y: number;
  y: number;
  z: 50%;
  z: number;
  z: number;
  z: true; }
