$foo: 400px;
$bar: "min-width:400px";
@import url(foo.css) (min-width:400px);
@import url(foo.css) (min-width:$foo);
@import url(foo.css) (min-width:#{$foo});
@import url(foo.css) ($bar);
@import url(foo.css) (#{$bar});
