@media screen and (orientation: landscape) { span { background: blue; }
  /* fudge */
  /* budge */
  div { color: red; } }
@media screen and (orientation: landscape) { /* crash */
  p { width: 100px; } }
