foo { color: blue; }

foo--modifier { color: red; }

foo { color: blue; }
foo bar { color: red; }

foo { color: blue; }
bar foo { color: red; }

foo { color: blue; }
bar baz { color: red; }

bar foo { color: red; }
bar foo baz { color: blue; }
