$quoted: "notification";
$unquoted: notification;

@function func($var) {
  @return $var;
}

foo {
  foo: func(notification);
  foo: #{notification};
  foo: #{$quoted};
  foo: $quoted;
  foo: #{$unquoted};
  foo: $unquoted;
}
