p {
  color: red;
  color: #990000;
  color: black;
  color: white;
  color: #999999;
  color: black;
  color: #333333;
  color: red;
  color: #990000;
  color: black;
  color: white;
  color: #999999;
  color: black;
  color: #333333;
}
