.bar{color1:rgba(192,152,83,0.5);color2:#c09853}.darken{color1:#a47e3c;color2:#7f612e;color3:#594521;color4:#342813;color5:#0f0b05;color6:#000;color7:#000;color8:#000;color9:#000;color10:#000}.lighten{color1:#ceae78;color2:#dbc59e;color3:#e9dbc3;color4:#f7f1e8;color5:#fff;color6:#fff;color7:#fff;color8:#fff;color9:#fff;color10:#fff}
