foo{test-1:false;test-2:false;test-3:false;test-4:false;test-5:false;test-6:false;test-7:false;test-8:false;test-9:true;test-10:true;test-11:true;test-12:true;test-13:true 0px;test-14:true 0px;test-15:true 0px;test-16:true 0px;test-17:false px;test-18:false px;test-19:false px;test-20:false px;test-21:false px;test-22:false px;test-23:false px;test-24:false px;test-25:false;test-26:false;test-27:false;test-28:false;test-29:true;test-30:true;test-31:true;test-32:true;test-33:true 0px;test-34:true 0px;test-35:true 0px;test-36:true 0px;test-37:false px;test-38:false px;test-39:false px;test-40:false px;test-41:false px;test-42:false px;test-43:false px;test-44:false px;test-45:false;test-46:false;test-47:false;test-48:false;test-49:true 0px;test-50:true 0px;test-51:true 0px;test-52:true 0px;test-53:true px;test-54:true px;test-55:true px;test-56:true px;test-57:true px;test-58:true px;test-59:true px;test-60:true px;test-61:1 true 0px;test-62:1 true 0px;test-63:1 true 0px;test-64:1 true 0px;test-65:1 true px;test-66:1 true px;test-67:1 true px;test-68:1 true px;test-69:1 true px;test-70:1 true px;test-71:1 true px;test-72:1 true px;test-73:10 true px;test-74:10 true px;test-75:10 true px;test-76:10 true px;test-77:10 true px;test-78:10 true px;test-79:10 true px;test-80:10 true px;test-81:10 true px;test-82:10 true px;test-83:10 true px;test-84:10 true px}
