div {
  $foo: null !default !global;
  $foo: inner !default !global;
  $foo: null !default !global;
  $foo: lexical;
  inner { foo: $foo; }
}

$foo: null !default !global;
$foo: outer !default !global;
$foo: null !default !global;
outer { foo: $foo; }

div {
  $foo: null !default !global;
  $foo: footer !default !global;
  $foo: null !default !global;
  $foo: lexical;
  inner { foo: $foo; }
}
