footer {
  color: red;
}

/*.button {
    &-primary {
        background: orange;
    }

    &-secondary {
        background: blue;
    }
}*/
.button-primary {
  background: orange;
}

.button-secondary {
  background: blue;
}
