@import "../assert_helpers";

test {
  a: assert_strict_superselector(':matches(.foo, .bar, .baz)', '#x:matches(.foo.bip, .baz.bang)');
  b: assert_strict_superselector(':-moz-any(.foo, .bar, .baz)', '#x:-moz-any(.foo.bip, .baz.bang)');
}