@mixin opacity($percent) {
  foo { test: opacity($percent); }
}

@-webkit-keyframes uiDelayedFadeIn {
  0% { @include opacity(0.01); }
  50% { @include opacity(0.01); }
  100% { @include opacity(1); }
}

@-webkit-keyframes bounce {
  from {
    left: 0px;
  }
  to {
    left: 200px;
  }
}

@-moz-document url-prefix() {
  .fl { float:left; margin:12px 4px 0 0; padding:0; font-size:65px; line-height:62%; color:#ba1820; }
  .fs { float:left; margin:12px 4px 10px 0; padding:0; font-size:65px; line-height:62%; color:#ba1820; }
}