foo bar baz {
  bam: true;
}
bar baz foo {
  bam: true;
}

foo bar + baz {
  bam: true;
}
bar + baz foo {
  bam: true;
}

foo bar > baz {
  bam: true;
}
bar > baz foo {
  bam: true;
}

foo bar ~ baz {
  bam: true;
}
bar ~ baz foo {
  bam: true;
}
