.result {
  output: (0Hz + 1Hz);
  output: (4.2Hz / 1Hz);
  output: (4.2Hz * 1Hz / 1Hz);
  output: (0Hz + 1kHz);
  output: (4.2Hz / 1kHz);
  output: (4.2Hz * 1kHz / 1Hz);
  output: (0kHz + 1Hz);
  output: (4.2kHz / 1Hz);
  output: (4.2kHz * 1Hz / 1kHz);
  output: (0kHz + 1kHz);
  output: (4.2kHz / 1kHz);
  output: (4.2kHz * 1kHz / 1kHz);
}
