.yellow-0 {
  background-color: white;
}

.yellow-100 {
  background-color: #fffffd;
}

.yellow-200 {
  background-color: #fffef3;
}

.yellow-300 {
  background-color: #fffde8;
}

.yellow-400 {
  background-color: #fffcde;
}

.yellow-500 {
  background-color: #fffbd4;
}

.yellow-600 {
  background-color: #fffaca;
}

.yellow-700 {
  background-color: #fff9c0;
}

.yellow-800 {
  background-color: #fff7b5;
}

.yellow-900 {
  background-color: #fff6ab;
}

.yellow-0 {
  background-color: #ffff33;
}

.yellow-100 {
  background-color: #ffff33;
}

.yellow-200 {
  background-color: #ffff33;
}

.red-0 {
  background-color: #ff3333;
}

.red-100 {
  background-color: #ff3333;
}

.red-200 {
  background-color: #ff3333;
}

.blue-0 {
  background-color: #3333ff;
}

.blue-100 {
  background-color: #3333ff;
}

.blue-200 {
  background-color: #3333ff;
}
