colors {
  AliceBlue:  #F0F8FF + 0;
  AntiqueWhite:  #FAEBD7 + 0;
  Aqua:  #00FFFF + 0;
  Aquamarine:  #7FFFD4 + 0;
  Azure:   #F0FFFF + 0;
  Beige:   #F5F5DC + 0;
  Bisque:  #FFE4C4 + 0;
  Black:   #000000 + 0;
  BlanchedAlmond:  #FFEBCD + 0;
  Blue:  #0000FF + 0;
  BlueViolet:  #8A2BE2 + 0;
  Brown:   #A52A2A + 0;
  BurlyWood:   #DEB887 + 0;
  CadetBlue:   #5F9EA0 + 0;
  Chartreuse:  #7FFF00 + 0;
  Chocolate:   #D2691E + 0;
  Coral:   #FF7F50 + 0;
  CornflowerBlue:  #6495ED + 0;
  Cornsilk:  #FFF8DC + 0;
  Crimson:   #DC143C + 0;
  Cyan:  #00FFFF + 0;
  DarkBlue:  #00008B + 0;
  DarkCyan:  #008B8B + 0;
  DarkGoldenRod:   #B8860B + 0;
  DarkGray:  #A9A9A9 + 0;
  DarkGreen:   #006400 + 0;
  DarkKhaki:   #BDB76B + 0;
  DarkMagenta:   #8B008B + 0;
  DarkOliveGreen:  #556B2F + 0;
  Darkorange:  #FF8C00 + 0;
  DarkOrchid:  #9932CC + 0;
  DarkRed:   #8B0000 + 0;
  DarkSalmon:  #E9967A + 0;
  DarkSeaGreen:  #8FBC8F + 0;
  DarkSlateBlue:   #483D8B + 0;
  DarkSlateGray:   #2F4F4F + 0;
  DarkTurquoise:   #00CED1 + 0;
  DarkViolet:  #9400D3 + 0;
  DeepPink:  #FF1493 + 0;
  DeepSkyBlue:   #00BFFF + 0;
  DimGray:   #696969 + 0;
  DodgerBlue:  #1E90FF + 0;
  FireBrick:   #B22222 + 0;
  FloralWhite:   #FFFAF0 + 0;
  ForestGreen:   #228B22 + 0;
  Fuchsia:   #FF00FF + 0;
  Gainsboro:   #DCDCDC + 0;
  GhostWhite:  #F8F8FF + 0;
  Gold:  #FFD700 + 0;
  GoldenRod:   #DAA520 + 0;
  Gray:  #808080 + 0;
  Green:   #008000 + 0;
  GreenYellow:   #ADFF2F + 0;
  HoneyDew:  #F0FFF0 + 0;
  HotPink:   #FF69B4 + 0;
  IndianRed:   #CD5C5C + 0;
  Indigo:    #4B0082 + 0;
  Ivory:   #FFFFF0 + 0;
  Khaki:   #F0E68C + 0;
  Lavender:  #E6E6FA + 0;
  LavenderBlush:   #FFF0F5 + 0;
  LawnGreen:   #7CFC00 + 0;
  LemonChiffon:  #FFFACD + 0;
  LightBlue:   #ADD8E6 + 0;
  LightCoral:  #F08080 + 0;
  LightCyan:   #E0FFFF + 0;
  LightGoldenRodYellow:  #FAFAD2 + 0;
  LightGray:   #D3D3D3 + 0;
  LightGreen:  #90EE90 + 0;
  LightPink:   #FFB6C1 + 0;
  LightSalmon:   #FFA07A + 0;
  LightSeaGreen:   #20B2AA + 0;
  LightSkyBlue:  #87CEFA + 0;
  LightSlateGray:  #778899 + 0;
  LightSteelBlue:  #B0C4DE + 0;
  LightYellow:   #FFFFE0 + 0;
  Lime:  #00FF00 + 0;
  LimeGreen:   #32CD32 + 0;
  Linen:   #FAF0E6 + 0;
  Magenta:   #FF00FF + 0;
  Maroon:  #800000 + 0;
  MediumAquaMarine:  #66CDAA + 0;
  MediumBlue:  #0000CD + 0;
  MediumOrchid:  #BA55D3 + 0;
  MediumPurple:  #9370DB + 0;
  MediumSeaGreen:  #3CB371 + 0;
  MediumSlateBlue:   #7B68EE + 0;
  MediumSpringGreen:   #00FA9A + 0;
  MediumTurquoise:   #48D1CC + 0;
  MediumVioletRed:   #C71585 + 0;
  MidnightBlue:  #191970 + 0;
  MintCream:   #F5FFFA + 0;
  MistyRose:   #FFE4E1 + 0;
  Moccasin:  #FFE4B5 + 0;
  NavajoWhite:   #FFDEAD + 0;
  Navy:  #000080 + 0;
  OldLace:   #FDF5E6 + 0;
  Olive:   #808000 + 0;
  OliveDrab:   #6B8E23 + 0;
  Orange:  #FFA500 + 0;
  OrangeRed:   #FF4500 + 0;
  Orchid:  #DA70D6 + 0;
  PaleGoldenRod:   #EEE8AA + 0;
  PaleGreen:   #98FB98 + 0;
  PaleTurquoise:   #AFEEEE + 0;
  PaleVioletRed:   #DB7093 + 0;
  PapayaWhip:  #FFEFD5 + 0;
  PeachPuff:   #FFDAB9 + 0;
  Peru:  #CD853F + 0;
  Pink:  #FFC0CB + 0;
  Plum:  #DDA0DD + 0;
  PowderBlue:  #B0E0E6 + 0;
  Purple:  #800080 + 0;
  Red:   #FF0000 + 0;
  RosyBrown:   #BC8F8F + 0;
  RoyalBlue:   #4169E1 + 0;
  SaddleBrown:   #8B4513 + 0;
  Salmon:  #FA8072 + 0;
  SandyBrown:  #F4A460 + 0;
  SeaGreen:  #2E8B57 + 0;
  SeaShell:  #FFF5EE + 0;
  Sienna:  #A0522D + 0;
  Silver:  #C0C0C0 + 0;
  SkyBlue:   #87CEEB + 0;
  SlateBlue:   #6A5ACD + 0;
  SlateGray:   #708090 + 0;
  Snow:  #FFFAFA + 0;
  SpringGreen:   #00FF7F + 0;
  SteelBlue:   #4682B4 + 0;
  Tan:   #D2B48C + 0;
  Teal:  #008080 + 0;
  Thistle:   #D8BFD8 + 0;
  Tomato:  #FF6347 + 0;
  Turquoise:   #40E0D0 + 0;
  Violet:  #EE82EE + 0;
  Wheat:   #F5DEB3 + 0;
  White:   #FFFFFF + 0;
  WhiteSmoke:  #F5F5F5 + 0;
  Yellow:  #FFFF00 + 0;
  YellowGreen:   #9ACD32 + 0;
  RebeccaPurple:   #663399 + 0;
  transparent:   transparent + 0;
}
