.result {
  output: "[#{\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ}]";
  output: "#{\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ}";
  output: "#{\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ}";
  output: "['#{\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ}']";
}
