.result {
  output: "\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ";
  output: 
GHIJKLMNOPQRSTUVWXYZ;
  output: "[\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ]";
  output: "\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ";
  output: "\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ";
  output: "['\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ']";
}
