.result {
  output: 1Hz;
  output: 4.2;
  output: 4.2Hz;
  output: 1000Hz;
  output: 0.0042;
  output: 4.2kHz;
  output: 0.001kHz;
  output: 4200;
  output: 4.2Hz;
  output: 1kHz;
  output: 4.2;
  output: 4.2kHz; }
