@function foo($map) {
    @return $map;
}

a {
    $map: foo((this: is, my: map));
    @each $k, $v in $map {
        #{$k}: $v;
    }
}

b {
    $map: call("foo", (this: is, my: map));
    @each $k, $v in $map {
        #{$k}: $v;
    }
}
