@mixin foo() {
  name: foo;
  @content;
  @include bar() {
    stuff: content for bar;
    @content;
  }
}

@mixin bar() {
  name: bar;
  @content;
}

div {
  /* with a content block */
  @include foo() {
    stuff: content for foo;
  }
  /* without */
  @include foo();
}

@mixin foo() {
  $size: 80%;
  div {
    color: red;
    @content;
    background: blue;
    width: $size;
    @include bar() {
      color: orange;
      @content;
    }
  }
}

@mixin bar() {
  form {
    @content;
  }
}

span {
  $size: 1.2em;
  color: green;
  @include foo() {
    @media fudge {
      p {
        font-weight: bold;
        font-size: $size;
        a {
          text-decoration: underline;
        }
      }
    }
  }
}

@mixin apply-to-ie6-only {
  * html {
    @content;
  }
}
@include apply-to-ie6-only {
  #logo {
    background-image: url(/logo.gif);
  }
}
