foo {
  // c-1: adjust-color(black,$alpha:-1);
  c0: adjust-color(black,$alpha:0.0);
  c1: adjust-color(black,$alpha:0.1);
  c2: adjust-color(black,$alpha:0.2);
  c3: adjust-color(black,$alpha:0.3);
  c4: adjust-color(black,$alpha:0.4);
  c5: adjust-color(black,$alpha:0.5);
  c6: adjust-color(black,$alpha:0.6);
  c7: adjust-color(black,$alpha:0.7);
  c8: adjust-color(black,$alpha:0.8);
  c9: adjust-color(black,$alpha:0.9);
  c10: adjust-color(black,$alpha:1);
  // c11: adjust-color(black,$alpha:1.1);
  // c12: adjust-color(black,$alpha:2);
}
