foo bar baz {
  bam: true;
}
baz foo bar {
  bam: true;
}

foo + bar baz {
  bam: true;
}
baz foo + bar {
  bam: true;
}

foo > bar baz {
  bam: true;
}
baz foo > bar {
  bam: true;
}

foo ~ bar baz {
  bam: true;
}
baz foo ~ bar {
  bam: true;
}
