input {
  color: blue;
  background: red;
}

* html #logo {
  background-image: url(/logo.gif);
}

.a + .c, .a + .b {
  margin: 10px;
  mix: in;
}

.a {
  mix: in;
}
.a + b .c, .a + b .b {
  margin: 10px;
}

.a > .c, .a > .b {
  margin: 10px;
}
