.result{dquoted:"foobarbaz";dquoted:"[foobarbaz]";dquoted:"foobarbaz";dquoted:"foobarbaz";dquoted:"['foobarbaz']";squoted:"foobarbaz";squoted:"[foobarbaz]";squoted:"foobarbaz";squoted:"foobarbaz";squoted:"['foobarbaz']"}
