$var: 1;
$list: 2, 3;
$new-list: append($var, $list);
$nested-list: $var $list;
@debug($var);
@debug($list);
@debug($new-list);
@debug($nested-list);
div {
 a: $var;
 a: $list;
 a: $new-list;
 a: $nested-list;
}