.alpha-hex {
  short-letters: #AbCd;
  long-letters: #aBcDeFaB;
  short-type: string;
  long-type: string;
  five-letters: #abcde;
  seven-letters: #abcdefa;
  nine-letters: #abcdefabc;
  non-hex-short: #axcd;
  non-hex-long: #abcxdefa;
}
