.multiple {
  multiple-numerators: 1px*rad;
  multiple-denominators: 1(px*rad)^-1;
  divide-by-multiple-numerators: 1(px*rad)^-1;
  divide-by-multiple-denominators: 1px*rad;
  multiplication-cancels-denominator: 1px*rad/Hz;
  multiplication-cancels-denominator-twice: 1px*rad;
  multiplication-cancels-numerator: 1rad/ms*Hz;
  multiplication-cancels-numerator-twice: 1(ms*Hz)^-1;
  multiplication-cancels-both: 1rad/Hz;
  division-cancels-numerator: 1px/ms*Hz;
  division-cancels-numerator-twice: 1(ms*Hz)^-1;
  division-cancels-denominator: 1px*rad/Hz;
  division-cancels-denominator-twice: 1px*rad;
  division-cancels-both: 1rad/Hz;
  multiplication-cancels-compatible: 1000px*rad/Hz;
  division-cancels-compatible: 0.0104166667rad/ms*Hz;
  multiplication-cancels-unknown: 1foo*bar/qux;
  division-cancels-unknown: 1bar/baz*qux;
}
