
foo {
    $id: unique-id();
    $is-string: type-of($id) == string;
    $starts-with-character: str_slice($id, 0, 1) == "u";
    $is-unique: $id != unique-id();

    @for $i from 1 through 1000 {
        $id: unique-id();
        $is-string: $is-string and type-of($id) == string;
        $starts-with-character: $starts-with-character and str_slice($id, 0, 1) == "u";
        $is-unique: $is-unique and $id != unique-id();
    }

    is-defined: $id != "unique-id()";
    is-string: $is-string;
    starts-with-character: $starts-with-character;
    is-unique: $is-unique;
}
