.result {
  dquoted: "\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ";
  dquoted: "[\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ]";
  dquoted: "\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ";
  dquoted: "\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ";
  dquoted: "['\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ']";
  squoted: "\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ";
  squoted: "[\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ]";
  squoted: "\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ";
  squoted: "\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ";
  squoted: "['\b\c\d\e\fGHIJKLMNOPQRSTUVWXYZ']";
}
