$x: global x;
$y: global y;

@mixin foo($x) {
  f-a: $x;
  f-b: $y;
  $x: local x changed by foo;
  $y: global y changed by foo !global;
  $z: new local z;
  f-a: $x;
  f-b: $y;
  f-c: $z;
}

div {
  a: $x;
  b: $y;
  @include foo(arg);
  a: $x;
  b: $y;
}
