test {
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
  border-top-color: #dadada;
}
