.result {
  output: 1dpi;
  output: 4.2;
  output: 4.2dpi;
  output: 2.54dpi;
  output: 1.6535433071;
  output: 4.2dpcm;
  output: 96dpi;
  output: 0.04375;
  output: 4.2dppx;
  output: 0.3937007874dpcm;
  output: 10.668;
  output: 4.2dpi;
  output: 1dpcm;
  output: 4.2;
  output: 4.2dpcm;
  output: 37.7952755906dpcm;
  output: 0.111125;
  output: 4.2dppx;
  output: 0.0104166667dppx;
  output: 403.2;
  output: 4.2dpi;
  output: 0.0264583333dppx;
  output: 158.7401574803;
  output: 4.2dpcm;
  output: 1dppx;
  output: 4.2;
  output: 4.2dppx;
}
