@mixin vararg-test($a, $b, $c, $d) {
  a: $a;
  b: $b;
  c: $c;
  d: $d;
}

foo {
  @include vararg-test(a, b, c, d);
}

foo {
  @include vararg-test(a b c d...);
}

foo {
  @include vararg-test((a b c d)...);
}

foo {
  @include vararg-test((a, b, c, d)...);
}

foo {
  @include vararg-test((a: a, b: b, c: c, d: d)...);
}

foo {
  @include vararg-test(("a": a, "b": b, "c": c, "d": d)...);
}

foo {
  @include vararg-test(a b..., (c: c, d: d)...);
}

foo {
  @include vararg-test(a, b c..., (d: d)...);
}

foo {
  @include vararg-test($c: c, (a: a, b: b, d: d)...);
}
