test {

  num_deg: 42 + 11deg;
  num_grad: 42 + 11grad;
  num_rad: 42 + 11rad;
  num_turn: 42 + 11turn;

  deg_num: 11deg + 42;
  deg_grad: 11deg + 42grad;
  deg_rad: 11deg + 42rad;
  deg_turn: 11deg + 1turn;

  grad_num: 11grad + 1.5;
  grad_rad: 11grad + 42rad;
  grad_turn: 11grad + 0.5turn;

  rad_num: 11rad + 1.5;
  rad_turn: 11rad + 0.5turn;

}
