foo{test-1:false;test-2:false;test-3:false;test-4:false;test-5:true;test-6:true;test-7:true;test-8:true;test-9:true 0;test-10:true 0;test-11:true 0;test-12:true 0;test-13:true;test-14:true;test-15:true;test-16:true;test-17:false;test-18:false;test-19:false;test-20:false;test-21:true 0;test-22:true 0;test-23:true 0;test-24:true 0;test-25:false;test-26:false;test-27:false;test-28:false;test-29:1 true 0;test-30:1 true 0;test-31:1 true 0;test-32:1 true 0;test-33:1 true;test-34:1 true;test-35:1 true;test-36:1 true;test-37:false;test-38:false;test-39:false;test-40:false}
