.my-element { -webkit-transition: -webkit-transform 0.25s linear, transform 0.25s linear; -moz-transition: -moz-transform 0.25s linear, transform 0.25s linear; -ms-transition: -ms-transform 0.25s linear, transform 0.25s linear; -o-transition: -o-transform 0.25s linear, transform 0.25s linear; transition: transform 0.25s linear; }
