.test {
  equal-01: true;
  equal-02: true;
  equal-03: true;
  equal-04: false;
  equal-05: false;
  equal-06: false;
  equal-07: false;
  equal-08: true;
  equal-09: true;
  equal-10: true;
  equal-11: false;
  equal-13: false;
  equal-14: true;
  equal-15: false;
  equal-16: false;
  equal-17: false;
  equal-18: true;
  equal-19: true;
  equal-20: false;
  equal-21: true;
  equal-22: true;
  equal-23: false;
  equal-24: true;
}
