%hoverbrighter {
    &:hover,
    &:focus {
        opacity: .8;

        @supports (filter: brightness(120%)) {
            filter: brightness(120%);
        }
    }
}

.productportal-link {
    @extend %hoverbrighter;
}