.result {
  output: "
GHIJKLMNOPQRSTUVWXYZ";
  output: 
GHIJKLMNOPQRSTUVWXYZ;
  output: "[
GHIJKLMNOPQRSTUVWXYZ]";
  output: "
GHIJKLMNOPQRSTUVWXYZ";
  output: "
GHIJKLMNOPQRSTUVWXYZ";
  output: "['
GHIJKLMNOPQRSTUVWXYZ']";
}
