p {
  color: adjust-hue(#f00, 10);
  color: adjust-hue(#900, 90);
  color: adjust-hue(#000, 30);
  color: adjust-hue(#fff, -30);
  color: adjust-hue(#999, -530);
  color: adjust-hue(#000, +720);
  // error in libsass
  // color: adjust-hue(#333, + 720);
}