.simple {
  a: selector-extend(".a .b", ".b", ".foo .bar");
  b: selector-extend('.foo .x', '.x', '.a .bar');
  c: selector-extend('.foo .x, .x.bar', '.x', '.bang');
  d: selector-extend('.y .x', '.x, .y', '.foo');
  e: selector-extend('.foo .x', '.x', '.bar, .bang');
  f: selector-extend('.foo.x', '.x', '.foo');
}
