.result {
  output: (0s + 1s);
  output: (4.2s / 1s);
  output: (4.2s * 1s / 1s);
  output: (0s + 1ms);
  output: (4.2s / 1ms);
  output: (4.2s * 1ms / 1s);
  output: (0ms + 1s);
  output: (4.2ms / 1s);
  output: (4.2ms * 1s / 1ms);
  output: (0ms + 1ms);
  output: (4.2ms / 1ms);
  output: (4.2ms * 1ms / 1ms);
}
