div {

  foo: length(null);
  foo: length(true);
  foo: length(false);

  foo: length("protégé");
  foo: length(protégé);
  foo: length("");
  foo: length("hello there");
  foo: length("Façade");
  foo: length("Tromsø");
  foo: length("Ãlso");

  foo: length((foo: foo, bar: bar));
  foo: length((foo, bar, baz, bang));

}
