.foo[disabled] {
    @extend .foo;
    background: blue;
  }
.bar[disabled] {
  foo {
    @extend .bar;
    background: blue;
  }
}
foo {
  .baz[disabled] {
    @extend .baz;
    background: blue;
  }
}