.simple {
  a: selector-replace('.foo', '.foo', '.bar');
  b: selector-replace('.foo.bar', '.bar', '.baz');
  c: selector-replace('.foo.bar', '.bar', '.a .baz');
  d: selector-replace('.foo.bar', '.baz.bar', '.qux');
  e: selector-replace('.foo.bar.baz', '.foo.baz', '.qux');
}