$a: 10px !global !default;
$b: 20px !default !global;
$c: 30px !default !default !default !global !global !global;
$d: 40px !global !global !global !default !default !default;
$e: 50px !global !default !global !default !global !default;

foo {
  a: $a;
  b: $b;
  c: $c;
  d: $d;
  e: $e;
}
