foo{test-1:true;test-2:true;test-3:true;test-4:true;test-5:true;test-6:true;test-7:true;test-8:true;test-9:false;test-10:false;test-11:false;test-12:false;test-13:false 0px;test-14:false 0px;test-15:false 0px;test-16:false 0px;test-17:true px;test-18:true px;test-19:true px;test-20:true px;test-21:true px;test-22:true px;test-23:true px;test-24:true px;test-25:true;test-26:true;test-27:true;test-28:true;test-29:false;test-30:false;test-31:false;test-32:false;test-33:false 0px;test-34:false 0px;test-35:false 0px;test-36:false 0px;test-37:true px;test-38:true px;test-39:true px;test-40:true px;test-41:true px;test-42:true px;test-43:true px;test-44:true px;test-45:true;test-46:true;test-47:true;test-48:true;test-49:false 0px;test-50:false 0px;test-51:false 0px;test-52:false 0px;test-53:false px;test-54:false px;test-55:false px;test-56:false px;test-57:false px;test-58:false px;test-59:false px;test-60:false px;test-61:1 false 0px;test-62:1 false 0px;test-63:1 false 0px;test-64:1 false 0px;test-65:1 false px;test-66:1 false px;test-67:1 false px;test-68:1 false px;test-69:1 false px;test-70:1 false px;test-71:1 false px;test-72:1 false px;test-73:10 false px;test-74:10 false px;test-75:10 false px;test-76:10 false px;test-77:10 false px;test-78:10 false px;test-79:10 false px;test-80:10 false px;test-81:10 false px;test-82:10 false px;test-83:10 false px;test-84:10 false px}
