.result{dquoted:"
ghijklmnopqrstuvwxyz";dquoted:"[
ghijklmnopqrstuvwxyz]";dquoted:"
ghijklmnopqrstuvwxyz";dquoted:"
ghijklmnopqrstuvwxyz";dquoted:"['
ghijklmnopqrstuvwxyz']";squoted:"
ghijklmnopqrstuvwxyz";squoted:"[
ghijklmnopqrstuvwxyz]";squoted:"
ghijklmnopqrstuvwxyz";squoted:"
ghijklmnopqrstuvwxyz";squoted:"['
ghijklmnopqrstuvwxyz']"}
