.test {
  foo: bar;
}
.test ~ {
  tilde: true;
}
.test + {
  adjancent: true;
}
.test > {
  child: true;
}
.test * {
  universal: true;
}
.test [foo] {
  attribute: true;
}

.selector-0 + .selector-1 {
  color: rebeccapurple;
}

multiple and,
multiple indented, lines and,
lines indented,
separated by and,
separated by indented,
commas and,
commas indented {
  x: y;
}
