foo bar {
    &:baz {
        bam: true;
    }
}

foo + bar {
    &:baz {
        bam: true;
    }
}

foo > bar {
    &:baz {
        bam: true;
    }
}

foo ~ bar {
    &:baz {
        bam: true;
    }
}
